@@ -4,8 +4,13 @@
 #' one of \code{bayesplot} package plotting functions.
 #'
 #' @param bg object of class \code{baggr}
-#' @param mean logical; plot mean treatment effect alongside individual study effects?
+#' @param hyper logical; show hypereffect as the last row of the plot?
 #' @param style one of \code{areas}, \code{intervals}
+#' @param transform a function (e.g. `exp()`, `log()`) to apply to the
+#'                  values of group (and hyper, if `hyper=TRUE`) effects
+#'                  before plotting; when working with effects that are on
+#'                  log scale, exponent transform is used automatically, you can
+#'                  plot on log scale by setting `transform = identity`
 #' @param prob Probability mass for the inner interval in visualisation
 #' @param prob_outer Probability mass for the outer interval in visualisation
 #' @param vline logical; show vertical line through 0 in the plot?
@@ -24,30 +29,52 @@
 #' @import bayesplot
 #'
 #' @author Witold Wiecek, Rachael Meager
-#' @seealso [bayesplot::MCMC-intervals]
+#' @seealso [bayesplot::MCMC-intervals] for more information about _bayesplot_ functionality;
+#'          [forest_plot] for a typical meta-analysis alternative; [effect_plot] for plotting
+#'          treatment effects for a new group
 
-baggr_plot <- function(bg, mean = FALSE,
+baggr_plot <- function(bg, hyper=FALSE,
                        style = "intervals",
+                       transform = NULL,
                        prob = 0.5, prob_outer = 0.95,
                        vline = TRUE, order = TRUE, ...) {
   if(attr(bg, "ppd")){
     message("Baggr model is prior predictive; returning effect_plot().")
     return(effect_plot(bg))
   }
-  m <- group_effects(bg)
+  m <- group_effects(bg, transform = transform)
+  if(hyper){
+    te <- treatment_effect(bg)$tau
+    if(!is.null(transform))
+      te <- do.call(transform, list(te))
+  }
+  effect_labels <- bg$effects
+
   if(!(style %in% c("areas", "intervals")))
     stop('plot "style" argument must be one of: "areas", "intervals"')
 
+  if(!is.null(transform))
+    vline_value <- do.call(transform, list(0))
+  else
+    vline_value <- 0
+
   ret_list <- lapply(as.list(1:dim(m)[3]), function(i) {
     if(order)
       mat_to_plot <- m[,order(apply(m[,,i], 2, mean)),i] #assigning to m[,,i] wouldn't reorder dimnames
     else
       mat_to_plot <- m[,,i]
+    if(hyper){
+      mat_to_plot <- cbind(mat_to_plot, te)
+      colnames(mat_to_plot)[ncol(mat_to_plot)] <- effect_labels[i]
+    }
     p <- switch(style,
                 "areas"     = bayesplot::mcmc_areas(mat_to_plot, prob = prob, prob_outer = prob_outer, ...),
                 "intervals" = bayesplot::mcmc_intervals(mat_to_plot, prob = prob, prob_outer = prob_outer, ...))
-    p + ggplot2::labs(x = paste("Effect size:", bg$effects[i])) +
-    {if(vline) geom_vline(xintercept = 0, lty = "dashed")}
+    p +
+      ggplot2::labs(x = paste("Effect size:", bg$effects[i])) +
+      baggr_theme_get() +
+      {if(hyper & style == "intervals") geom_hline(yintercept = 1.5)} +
+      {if(vline) geom_vline(xintercept = vline_value, lty = "dashed")}
   })
 
   if(length(ret_list) == 1)
