@@ -23,7 +23,7 @@
 #'          or to run models which you modified yourself.
 #'
 #'
-#' @author Witold Wiecek, Rachael Meager
+#' @author Witold Wiecek
 #' @examples
 #' # simple meta-analysis example:
 #' convert_inputs(schools, "rubin")
@@ -40,13 +40,22 @@ convert_inputs <- function(data,
   # check what kind of data is required for the model & what's available
   model_data_types <- c("rubin" = "pool_noctrl_narrow",
                         "mutau" = "pool_wide",
+                        "logit" = "individual_binary",
                         "full" = "individual",
-                        "quantiles" = "individual") #for now no quantiles model from summary level data
+                        #for now no quantiles model from summary level data
+                        "quantiles" = "individual")
   data_type_names <- c("pool_noctrl_narrow" = "Aggregate (effects only)",
                        "pool_wide" = "Aggregate (control and effects)",
-                       "individual" = "Individual-level")
-  available_data <- detect_input_type(data, group)
+                       "individual" = "Individual-level with continuous outcome",
+                       "individual_binary" = "Individual-level with binary outcome")
 
+  available_data <- detect_input_type(data, group, treatment, outcome)
+
+  if(!is.null(test_data)){
+    available_data_test <- detect_input_type(test_data, group, treatment, outcome)
+    if(available_data != available_data_test)
+      stop("'test_data' is of type ", available_data_test, " and 'data' is of type ", available_data)
+  }
   # if(available_data == "unknown")
   # stop("Cannot automatically determine type of input data.")
   # let's assume data is individual-level
@@ -55,9 +64,11 @@ convert_inputs <- function(data,
   if(available_data == "unknown")
     available_data <- "individual" #in future can call it 'inferred ind.'
 
-  if(available_data == "individual")
+  if(grepl("individual", available_data)){
     check_columns(data, outcome, group, treatment)
-
+    if(!is.null(test_data))
+      check_columns(data, outcome, group, treatment)
+  }
   if(is.null(model)) {
     message("Attempting to infer the correct model for data.")
     # we take FIRST MODEL THAT SUITS OUR DATA!
@@ -68,11 +79,6 @@ convert_inputs <- function(data,
       stop("Unrecognised model, can't format data.")
   }
 
-  # Prompt and stop conversion for the CRAN release version of the package:
-  # if(model != "rubin")
-    # stop("In baggr v0.1 only Rubin model is enabled.
-  # More models will be available in the next release.")
-
   # Convert mutau data to Rubin model data if requested
   # (For now disabled as it won't work with functions that then
   #  re-use the input data)
@@ -92,29 +98,47 @@ convert_inputs <- function(data,
   #for now this means no automatic conversion of individual->pooled
 
   # individual level data -----
-  if(required_data == "individual"){
-    # # check correctness of inputs:
-    # (This check moved up now.)
-    # if(is.null(data[[group]]))
-    #   stop("No 'group' column in data.")
-    # if(is.null(data[[outcome]]))
-    #   stop("No outcome column in data.")
-    # if(is.null(data[[treatment]]))
-    #   stop("No treatment column in data.")
+  if(grepl("individual", required_data)) {
 
     groups <- as.factor(as.character(data[[group]]))
     group_numeric <- as.numeric(groups)
     group_label <- levels(groups)
 
-    if(model == "full")
+    if(!is.null(test_data)) {
+      groups_test <- as.factor(as.character(test_data[[group]]))
+      group_numeric_test <- as.numeric(groups_test)
+      group_label_test <- levels(groups_test)
+      if(any(group_label_test %in% group_label))
+        message(
+          "Test data has some groups that have same labels as groups in data. ",
+          "For cross-validation they will be treated as 'new' groups.")
+    }
+
+    if(model %in% c("full", "logit")){
       out <- list(
         K = max(group_numeric),
         N = nrow(data),
         P = 2, #will be dynamic
         y = data[[outcome]],
-        ITT = data[[treatment]],
+        treatment = data[[treatment]],
         site = group_numeric
       )
+    }
+    if(model == "logit") {
+      if(is.null(test_data)) {
+        out$N_test <- 0
+        out$K_test <- 0
+        out$test_y <- array(0, dim = 0)
+        out$test_site <- array(0, dim = 0)
+        out$test_treatment <- array(0, dim = 0)
+      } else {
+        out$N_test <- nrow(test_data)
+        out$K_test <- max(group_numeric_test)
+        out$test_y <- test_data[[outcome]]
+        out$test_treatment <- test_data[[treatment]]
+        out$test_site <- group_numeric_test
+      }
+    }
     if(model == "quantiles"){
       if((any(quantiles < 0)) ||
          (any(quantiles > 1)))
@@ -123,7 +147,7 @@ convert_inputs <- function(data,
         stop("cannot model less then 2 quantiles")
       data[[group]] <- group_numeric
       # out <- summarise_quantiles_data(data, quantiles,
-                                      # outcome, group, treatment)
+      # outcome, group, treatment)
       message("Data have been automatically summarised for quantiles model.")
 
       # Fix for R 3.5.1. on Windows
@@ -132,26 +156,28 @@ convert_inputs <- function(data,
       out$y_0 <- NULL
       out[["y_0"]] <- out$temp
       out$temp <- NULL
-    }
 
-    # Cross-validation:
-    if(is.null(test_data)){
-      out$K_test <- 0
-      out$test_tau_hat_k <- array(0, dim = 0)
-      out$test_se_k <- array(0, dim = 0)
-      out$test_y_0 <- array(0, dim = c(0, ncol(out$y_0)))
-      out$test_y_1 <- array(0, dim = c(0, ncol(out$y_0)))
-      out$test_Sigma_y_k_0 <- array(0, dim = c(0, ncol(out$y_0), ncol(out$y_0)))
-      out$test_Sigma_y_k_1 <- array(0, dim = c(0, ncol(out$y_0), ncol(out$y_0)))
-    } else {
-      # Disabled until summarise_quantiles_data() gets included in the release again.
-      # out_test <- summarise_quantiles_data(test_data, quantiles,
-                                      # outcome, group, treatment)
-      # out$K_test <- out_test$K #reminder: K is number of sites, N is number of quantiles
-      # out$test_y_0 <- out_test$y_0
-      # out$test_y_1 <- out_test$y_1
-      # out$test_Sigma_y_k_0 <- out_test$Sigma_y_k_0
-      # out$test_Sigma_y_k_1 <- out_test$Sigma_y_k_1
+      # Cross-validation:
+      if(is.null(test_data)){
+        out$K_test <- 0
+        out$test_tau_hat_k <- array(0, dim = 0)
+        out$test_se_k <- array(0, dim = 0)
+        out$test_y_0 <- array(0, dim = c(0, ncol(out$y_0)))
+        out$test_y_1 <- array(0, dim = c(0, ncol(out$y_0)))
+        out$test_Sigma_y_k_0 <- array(0, dim = c(0, ncol(out$y_0), ncol(out$y_0)))
+        out$test_Sigma_y_k_1 <- array(0, dim = c(0, ncol(out$y_0), ncol(out$y_0)))
+      } else {
+        # Disabled until summarise_quantiles_data() gets included
+        # in the release again.
+        # out_test <- summarise_quantiles_data(test_data, quantiles,
+        # outcome, group, treatment)
+        # out$K_test <- out_test$K #reminder: K is number of sites,
+        # N is number of quantiles
+        # out$test_y_0 <- out_test$y_0
+        # out$test_y_1 <- out_test$y_1
+        # out$test_Sigma_y_k_0 <- out_test$Sigma_y_k_0
+        # out$test_Sigma_y_k_1 <- out_test$Sigma_y_k_1
+      }
     }
   }
 
@@ -159,7 +185,8 @@ convert_inputs <- function(data,
   if(required_data == "pool_noctrl_narrow"){
     group_label <- data[[group]]
     if(is.null(data[[group]]) && (group != "group"))
-      warning(paste0("Column '", group, "' does not exist in data. No labels will be added."))
+      warning(paste0("Column '", group,
+                     "' does not exist in data. No labels will be added."))
     check_columns_numeric(data[,c("tau", "se")])
     out <- list(
       K = nrow(data),
@@ -187,7 +214,8 @@ convert_inputs <- function(data,
     group_label <- data[[group]]
     group_label <- data[[group]]
     if(is.null(data[[group]]) && (group != "group"))
-      warning(paste0("Column '", group, "' does not exist in data. No labels will be added."))
+      warning(paste0("Column '", group,
+                     "' does not exist in data. No labels will be added."))
     check_columns_numeric(data[,c("tau", "se.tau", "mu", "se.mu")])
     nr <- nrow(data)
     out <- list(
@@ -224,6 +252,7 @@ convert_inputs <- function(data,
 
   return(structure(
     out,
+    data_type = available_data,
     group_label = group_label,
     n_groups = out[["K"]],
     model = model))
